@@ -1,12 +1,10 @@
 import tkinter as tk
 
 from subsearch.data import __icon__
-from subsearch.gui import tk_data, tk_tools
+from subsearch.data.data_fields import TkColor, TkWindowSize
+from subsearch.gui import tk_tools
 from subsearch.utils import current_user, raw_config, raw_registry
 
-TKWINDOW = tk_data.Window()
-TKCOLOR = tk_data.Color()
-
 
 def check_state(event):
     if hidden_root.state() == "iconic":
@@ -17,11 +15,11 @@ def check_state(event):
 
 def main():
     global root, hidden_root
-    if current_user.got_key() is False:
+    if current_user.registry_key_exists() is False:
         raw_config.set_default_json()
         raw_registry.add_context_menu()
     hidden_root = tk.Tk(className=f"subsearch")
-    hidden_root.configure(background=TKCOLOR.black)
+    hidden_root.configure(background=TkColor().black)
     hidden_root.iconbitmap(__icon__)
     hidden_root.geometry(tk_tools.WindowPosition.set(hidden_root))
     hidden_root.attributes("-alpha", 0)
@@ -30,8 +28,8 @@ def main():
     root.geometry(tk_tools.WindowPosition.set(root))
     root.overrideredirect(1)
     tk_tools.CustomBorder(root).place(relx=0.5, rely=0.5, anchor="center")
-    tk.Frame(root, height=40, bg=TKCOLOR.dark_grey).pack(anchor="center", expand=True)
-    tk_tools.TitleBar(root, hidden_root).place(x=TKWINDOW.width - 2, y=2, bordermode="inside", anchor="ne")
+    tk.Frame(root, height=40, bg=TkColor().dark_grey).pack(anchor="center", expand=True)
+    tk_tools.TitleBar(root, hidden_root).place(x=TkWindowSize().width - 2, y=2, bordermode="inside", anchor="ne")
     hidden_root.bind("<FocusOut>", check_state)
     hidden_root.bind("<FocusIn>", check_state)
     return root
