@@ -179,6 +179,7 @@ class TabSettings(tk.Frame):
         tab_subsearch.ShowContextMenu(self).pack(anchor="center")
         tab_subsearch.ShowContextMenuIcon(self).pack(anchor="center")
         tab_subsearch.ShowDownloadWindow(self).pack(anchor="center")
+        tab_subsearch.LogToFile(self).pack(anchor="center")
         if current_user.running_from_exe() is False:
             tab_subsearch.ShowTerminalOnSearch(self).pack(anchor="center")
         tk.Frame(self, height=20, bg=TkColor().dark_grey).pack(anchor="center", expand=True)
@@ -196,7 +197,7 @@ def open_tab(active_tab: str, **kwargs):
     try:
         formatted_data: list[FormattedData] = kwargs["formatted_data"]
     except KeyError:
-        formatted_data = None
+        formatted_data = None  # type: ignore
     root = base_root.main()
     gui.set_theme("dark")
     content = tk.Frame(root, bg=TkColor().dark_grey, width=TkWindowSize().width - 4, height=TkWindowSize().height - 118)
