@@ -9,13 +9,20 @@ from subsearch.data.data_fields import (
     ReleaseData,
     UserData,
 )
+from subsearch.utils import raw_config
 
 NOW = datetime.now()
 DATE = NOW.strftime("%y%m%d")
+LOG_TO_FILE = raw_config.get_config_key("log_to_file")
+
+release_data: ReleaseData
+user_data: UserData
+url_data: ProviderUrlData
 
 logger = logging.getLogger("subsearch")
 logger.setLevel(logging.DEBUG)
-if __video__ is not None:
+
+if __video__ is not None and LOG_TO_FILE:
     formatter = logging.Formatter("%(asctime)s - %(levelname)s - %(message)s", datefmt="%d-%b-%y %H:%M:%S")
     file_handler = logging.FileHandler(Path(__video__.directory) / "subsearch.log", "w")
     file_handler.setLevel(logging.INFO)
@@ -25,7 +32,7 @@ if __video__ is not None:
 
 def output(msg: str, terminal: bool = True, level: str = "info"):
     def _to_log(msg: str, level: str) -> None:
-        if __video__ is None:
+        if __video__ is None or LOG_TO_FILE is False:
             return None
         if level == "info":
             logger.info(msg)
@@ -144,7 +151,7 @@ def output_subtitle_result(to_be_downloaded: dict[str, str], to_be_sorted: list[
     output("")
 
 
-def output_title_data_result(found: bool, from_hash: str = False):
+def output_title_data_result(found: bool, from_hash: bool = False):
     def _not_found(media_type: str, from_hash: bool):
         if from_hash:
             output(f"Did not find a {media_type} matching hash: {release_data.file_hash}")
